<?php declare(strict_types = 1);

namespace Modules\Example\Actions;

use CController as Action;
use CControllerResponseData;

/**
 * Example module action. Action class should extend base CController.
 */
class ExamplesListAction extends Action {
	/**
	 * Optional method, called by Zabbix core to initialize action. There will be no user input available at this point
	 * via $this->getInput or $this->hasInput methods.
	 */
	public function init() {
		/**
		 * SID validation should be disabled otherwise action will not start if supplied sid is not same as part of
		 * user session string value.
		 */
		$this->disableSIDvalidation();
	}

	/**
	 * Required method, called after $this->init and before $this->checkPermissions it return user supplied data
	 * validation status, false if supplied data is invalid. In case of invalid user input no $this->checkPermissions
	 * will be called. Can return custom error messages.
	 *
	 * NOTE: Only fields passed validation will be available via $this->getInput and/or $this->hasInput methods.
	 *
	 * @return bool
	 */
	public function checkInput() {
		return true;
	}

	/**
	 * Required method, called after $this->checkInput and before $this->doAction, it return user ability access current
	 * action, false if user does not have access. In case of no access no $this->doAction will be not called.
	 *
	 * @return bool
	 */
	public function checkPermissions() {
		$user_type = [USER_TYPE_ZABBIX_USER, USER_TYPE_ZABBIX_ADMIN, USER_TYPE_SUPER_ADMIN];

		return in_array($this->getUserType(), $user_type);
	}

	/**
	 * Required method, called to render action response for request. Response should be set via $this->setResponse.
	 */
	public function doAction() {
		$data = [
			'links' => [
				['url' => 'zabbix.php?action=demo.redirect.success', 'name' => 'Example #1', 'description' => 'Redirect to dashboard with success message.'],
				['url' => 'zabbix.php?action=demo.redirect.error', 'name' => 'Example #2', 'description' => 'Redirect to dashboard with error message.']
			]
		];

		// $data Array of data to be passed to view file.
		$response = new CControllerResponseData($data);
		$response->setTitle('Examples page');
		$this->setResponse($response);
	}
}