<?php declare(strict_types = 1);

namespace Modules\Example\Actions;

use CController as Action;
use CControllerResponseRedirect;

/**
 * Example module action. Action class should extend base CController.
 */
class RedirectDashboardAction extends Action {
	/**
	 * Optional method, called by Zabbix core to initialize action. There will be no user input available at this point
	 * via $this->getInput or $this->hasInput methods.
	 */
	public function init() {
		/**
		 * SID validation should be disabled otherwise action will not start if supplied sid is not same as part of
		 * user session string value.
		 */
		$this->disableSIDvalidation();
	}

	/**
	 * Required method, called after $this->init and before $this->checkPermissions it return user supplied data
	 * validation status, false if supplied data is invalid. In case of invalid user input no $this->checkPermissions
	 * will be called. Can return custom error messages.
	 *
	 * NOTE: Only fields passed validation will be available via $this->getInput and/or $this->hasInput methods.
	 *
	 * @return bool
	 */
	public function checkInput() {
		return true;
	}

	/**
	 * Required method, called after $this->checkInput and before $this->doAction, it return user ability access current
	 * action, false if user does not have access. In case of no access no $this->doAction will be not called.
	 */
	public function checkPermissions() {
		return true;
	}

	/**
	 * Required method, called to render action response for request. Response should be set via $this->setResponse.
	 */
	public function doAction() {
		$response = new CControllerResponseRedirect('zabbix.php?action=dashboard.view');

		if ($this->getAction() == 'demo.redirect.success') {
			$response->setMessageOk(_('Success message'));
		}
		else {
			$response->setMessageError(_('Error message'));
		}

		$this->setResponse($response);
	}
}